@@ -3,8 +3,13 @@ import os
 import datetime
 import inspect
 
-jsonpickle.set_encoder_options('simplejson', indent=4)
-jsonpickle.set_encoder_options('demjson', compactly=False)
+jsonpickle.set_preferred_backend('json')
+
+def pretty_print():
+    jsonpickle.set_encoder_options('json', indent=2)
+
+def ugly_print():
+    jsonpickle.set_encoder_options('json', indent=None)
 
 class List:
     def __init__(self, item_type):
